
;  Revised routines for pushing, popping, and toggling
;  AutoCAD system variables.

;  by Duff Kurland - Autodesk, Inc.   September 22, 1986


;  (VTOGGLE "VAR")  toggles the named system variable on or off.
;  This should be used only for variables that contain 0 (off)
;  or 1 (on).  Example:  (VTOGGLE "BLIPMODE")

(defun vtoggle (v)
   (setvar v (xor (getvar v) 1))
)
(defun xor (a b) (Boole 6 a b))       ; Exclusive-OR function



;  (VSAVE "VAR" VALUE)  saves current value of a system variable
;  and sets a new value.  Example:  (VSAVE "BLIPMODE" 0)

(defun vsave (var val)
   (if (null vars) (setq vars '()))   ; Begin with a null list
   (setq vars
      (cons (list var (getvar var))   ; Add old value to save list
            vars
      )
   )
   (setvar var val)                   ; Set new value
)



;  (VRESTORE "VAR")  restores specified system variable to the value saved
;  by (VSAVE), and discards saved value.  Example:  (VRESTORE "BLIPMODE")

(defun vrestore (var / sv)
   (if (null (setq sv (assoc var vars)))
       (strcat (strcase var) " not in list of saved variables.")
       (progn
          (setq vars (remove sv vars))  ; Remove var from save list
          (setvar var (cadr sv))        ; Restore previous value
       )
   )
)



;  (VRESTALL)  takes no arguments.  It restores all system variables
;  to the values saved by (VSAVE), and discards the saved values.

(defun vrestall ( / sv)
   (while (> (length vars) 0)
      (setq sv (car vars))            ; For each save variable
      (setvar (car sv) (cadr sv))     ; Restore previous value
      (setq vars (cdr vars))          ; Remove from save list
   )
)


; Remove item E from list LST, return what's left.  Used by VRESTORE

(defun remove (e lst)
   (cond ((null lst) nil)
         ((equal e (car lst)) (cdr lst))
         (T (append (list (car lst))
                    (remove e (cdr lst))))
   )
)
